# py-noide

Barebones and minimalistic web code editor for Python.
Not intended to actually be used by anyone.
Only created to learn how to package python packages.

## How to use

Either run the command,
```
pyide_run
```

run the module directly,
```
python -m no_pyide
```

or import and run.
```python
from no_pyide import code

code.main()

```




